# clashroyale
This library is currently an (a)sync wrapper for https://cr-api.com with great functionality.

## Installation
```
pip install clashroyale
```

## Documentation
Currently we dont have any documentation, read through the source / examples to get a feel on how to use the wrapper. If you would like to contribute to documentation, message kyber on [this](https://discord.gg/nBd7cp6) discord server or create a pull request.

## Misc

If you have any clash royale related code you would like to share, we could incorporate it into this library since its name is very generic, i.e. it refers to the game as a whole.
